# -*- coding: utf-8 -*-
#
# Copyright Grégory Soutadé 2015

# This file is part of iwla

# iwla is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# iwla is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with iwla.  If not, see <http://www.gnu.org/licenses/>.
#

import re

from iwla import IWLA
from iplugin import IPlugin

#
# Post analysis hook
# 
# Count TOP downloads
#
# Plugin requirements :
#     None
#
# Conf values needed :
#     None
#
# Output files :
#     None
#
# Statistics creation :
#     None
#
# Statistics update :
# month_stats:
#    top_downloads =>
#        uri
#
# Statistics deletion :
#     None
#

class IWLAPostAnalysisTopDownloads(IPlugin):
    def __init__(self, iwla):
        super(IWLAPostAnalysisTopDownloads, self).__init__(iwla)
        self.API_VERSION = 1
        self.conf_requires = ['multimedia_files', 'viewed_http_codes']

    def hook(self):
        stats = self.iwla.getCurrentVisists()
        month_stats = self.iwla.getMonthStats()

        multimedia_files = self.iwla.getConfValue('multimedia_files')
        viewed_http_codes = self.iwla.getConfValue('viewed_http_codes')

        top_downloads = month_stats.get('top_downloads', {})

        for (k, super_hit) in stats.items():
            if super_hit['robot']: continue
            for r in super_hit['requests'][::-1]:
                if not self.iwla.isValidForCurrentAnalysis(r):
                    break
                if not self.iwla.hasBeenViewed(r) or\
                        r['is_page']:
                    continue

                uri = r['extract_request']['extract_uri'].lower()

                isMultimedia = False
                for ext in multimedia_files:
                    if uri.endswith(ext):
                        isMultimedia = True
                        break

                if isMultimedia: continue

                uri = "%s%s" % (r.get('server_name', ''),
                                r['extract_request']['extract_uri'])

                if not uri in top_downloads.keys():
                    top_downloads[uri] = 1
                else:
                    top_downloads[uri] += 1

        month_stats['top_downloads'] = top_downloads
